midiogre.augmentations package
==========================

Submodules
----------

midiogre.augmentations.duration\_shift module
-------------------------------------------

.. automodule:: midiogre.augmentations.duration_shift
   :members:
   :undoc-members:
   :show-inheritance:

midiogre.augmentations.note\_add module
-------------------------------------

.. automodule:: midiogre.augmentations.note_add
   :members:
   :undoc-members:
   :show-inheritance:

midiogre.augmentations.note\_delete module
---------------------------------------

.. automodule:: midiogre.augmentations.note_delete
   :members:
   :undoc-members:
   :show-inheritance:

midiogre.augmentations.onset\_time\_shift module
--------------------------------------------

.. automodule:: midiogre.augmentations.onset_time_shift
   :members:
   :undoc-members:
   :show-inheritance:

midiogre.augmentations.pitch\_shift module
--------------------------------------

.. automodule:: midiogre.augmentations.pitch_shift
   :members:
   :undoc-members:
   :show-inheritance:

midiogre.augmentations.tempo\_shift module
--------------------------------------

.. automodule:: midiogre.augmentations.tempo_shift
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
--------------

.. automodule:: midiogre.augmentations
   :members:
   :undoc-members:
   :show-inheritance: 